==> lwat_0.16.orig.tar.gz: lwat/lib/buildconf.php <==
<?php
/*
    LWAT, LDAP Webbased Administration Tool
    Copyright (C) 2007 Finn-Arne Johansen <faj@bzz.no> BzzWare AS, Norway

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

    require_once ('functions.php') ; 

    loadConfig () ; 

printf ("<?php\n\n") ; 

printf ("\$domain = \"%s\" ; \n", $domain) ; 
printf ("\$base = \"%s\" ; \n", $base ) ; 
printf ("\$ldaphost = \"%s\" ; \n", $ldaphost) ;
printf ("\$groupprefix = \"%s\" ; \n", $groupprefix)  ;
if ($useLisGroup === false) 
    printf ("\$authprefix = \"%s\" ; \n", $authprefix) ;
printf ("\$hostprefix = \"%s\" ; \n", $hostprefix) ; 
printf ("\$netgroupprefix = \"%s\" ; \n", $netgroupprefix) ; 
printf ("\$homelocation = \"%s\" ; \n", $homelocation) ; 
printf ("\$useLisGroup = %s ; \n", ($useLisGroup ? "true" : "false") ) ; 
printf ("\$minPwLength = \"%s\" ; \n", $minPwLength) ; 
printf ("\$minPwUpper = \"%s\" ; \n", $minPwUpper) ; 
printf ("\$minPwLower = \"%s\" ; \n", $minPwLower) ; 
printf ("\$minPwNumber = \"%s\" ; \n", $minPwNumber) ; 
printf ("\$allowPwSet = %s ; \n\n", ($allowPwSet ? "true" : "false") ) ; 

printf ("\$smarty_templ = \"%s\" ; \n", $smarty_templ) ; 
printf ("\$smarty_compile = \"%s\" ; \n\n", $smarty_compile) ; 
printf ("?>\n") ;

?>

==> lwat_0.17.orig.tar.gz: lwat/lib/buildconf.php <==
<?php
/*
    LWAT, LDAP Webbased Administration Tool
    Copyright (C) 2007 Finn-Arne Johansen <faj@bzz.no> BzzWare AS, Norway

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

    require_once ('functions.php') ; 

    loadConfig () ; 

printf ("<?php\n\n") ; 

printf ("\$ldaphost = \"%s\" ; \n", $ldaphost) ;
printf ("\$domain = \"%s\" ; \n", $domain) ; 
printf ("\$base = \"%s\" ; \n", $base ) ; 

if (isset ($groupprefix))
    printf ("\$groupprefix = \"%s\" ; \n", $groupprefix)  ;
else
    printf ("\$groupbase = \"%s\" ; \n", $groupbase)  ;

if ($useLisGroup) 
    printf ("\$useLisGroup = %s ; \n", ($useLisGroup ? "true" : "false") ) ; 
elseif (isset ($authprefix))
    printf ("\$authprefix = \"%s\" ; \n", $authprefix) ;
else
    printf ("\$authbase = \"%s\" ; \n", $authbase) ;

if (isset ($hostprefix))
    printf ("\$hostprefix = \"%s\" ; \n", $hostprefix) ; 
else
    printf ("\$hostbase = \"%s\" ; \n", $hostbase) ; 
    
if (isset ($netgroupprefix))
    printf ("\$netgroupprefix = \"%s\" ; \n", $netgroupprefix) ; 
else
    printf ("\$netgroupbase = \"%s\" ; \n", $netgroupbase) ; 

printf ("\$homelocation = \"%s\" ; \n", $homelocation) ; 
printf ("\$minPwLength = \"%s\" ; \n", $minPwLength) ; 
printf ("\$minPwUpper = \"%s\" ; \n", $minPwUpper) ; 
printf ("\$minPwLower = \"%s\" ; \n", $minPwLower) ; 
printf ("\$minPwNumber = \"%s\" ; \n", $minPwNumber) ; 
printf ("\$allowPwSet = %s ; \n\n", ($allowPwSet ? "true" : "false") ) ; 

printf ("\$smarty_templ = \"%s\" ; \n", $smarty_templ) ; 
printf ("\$smarty_compile = \"%s\" ; \n", $smarty_compile) ; 
printf ("\n?>\n") ; 

?>
